package cli;

import org.apache.commons.cli.*;

public class CommandLineInterface {

    private Options options;

    public CommandLineInterface(){
        this.options = new Options();
        addOptions();
        HelpFormatter formatter = new HelpFormatter();
        formatter.printHelp( "git ddit -n <title> | -rm <id> | -u <id> | -c <id> ", options);
//        options.addOption("create", "create an issue");
//        options.addOption("push", "push issues");
    }

    public void addOptions(){

        OptionGroup uniqueCommands = new OptionGroup();

        Option createIssue = Option.builder("n")
                .longOpt("new")
                .argName("title")
                .hasArg()
                .desc("create new issue with given title")
                .build();
        uniqueCommands.addOption(createIssue);

        Option updateIssue = Option.builder("u")
                .longOpt("update")
                .argName("id")
                .hasArg()
                .desc("update issue with given id")
                .build();
        uniqueCommands.addOption(updateIssue);

        Option deleteIssue = Option.builder("rm")
                .longOpt("remove")
                .argName("id")
                .hasArg()
                .desc("delete issue with given id")
                .build();
        uniqueCommands.addOption(deleteIssue);

        Option comment = Option.builder("c")
                .longOpt("comment")
                .argName("id")
                .hasArg()
                .desc("comment on issue with given id")
                .build();
        uniqueCommands.addOption(comment);

        Option viewIssues = Option.builder("v")
                .longOpt("comment")
                .argName("id")
                .hasArg()
                .desc("comment on issue with given id")
                .build();
        uniqueCommands.addOption(viewIssues);

        Option description = Option.builder("d")
                .longOpt("desc")
                .argName("desc")
                .hasArg()
                .required(false)
                .desc("get the description for an issue")
                .build();
        Option assignees = Option.builder("a")
                .longOpt("assignees")
                .argName("assignees")
                .hasArg()
                .required(false)
                .desc("people assigned to an issue")
                .build();
        Option label = Option.builder("l")
                .longOpt("label")
                .argName("label")
                .hasArg()
                .required(false)
                .desc("label assigned to an issue")
                .build();

        uniqueCommands.setRequired(true);
        options.addOptionGroup(uniqueCommands);
        options.addOption(description);
        options.addOption(assignees);
        options.addOption(label);
    }

    public CommandLine getInput(String[] userInput) throws ParseException {
        CommandLineParser parser = new DefaultParser();
        return parser.parse(options, userInput);
    }
}
